def read_scopes(file_path: str) -> dict:
    """
    Read file.json and return a dict of data
    """
    import json

    with open(file_path) as json_file:
        data: dict = json.load(json_file)
        return data



import secrets
import string


def read_content(filename: str):
    with open(filename, "r", encoding='utf-8') as f:
        text = f.read()
    return text


def gen_password():
    alphabet = string.ascii_letters + string.digits
    password = ''.join(secrets.choice(alphabet) for i in range(8))
    return password
